@@ -25,18 +25,37 @@ rhub::check_for_cran()
 ## sent to CRAN, or to a package manager
 devtools::build()
 
-## RStudio ----
-## If you want to deploy on RStudio related platforms
-golem::add_rstudioconnect_file()
+## Docker ----
+## If you want to deploy via a generic Dockerfile
+golem::add_dockerfile_with_renv()
+## If you want to deploy to ShinyProxy
+golem::add_dockerfile_with_renv_shinyproxy()
+
+## Posit ----
+## If you want to deploy on Posit related platforms
+golem::add_positconnect_file()
 golem::add_shinyappsio_file()
 golem::add_shinyserver_file()
 
-## Docker ----
-## If you want to deploy via a generic Dockerfile
-golem::add_dockerfile()
+## Deploy to Posit Connect or ShinyApps.io ----
 
-## If you want to deploy to ShinyProxy
-golem::add_dockerfile_shinyproxy()
+## Add/update manifest file (optional; for Git backed deployment on Posit )
+rsconnect::writeManifest()
 
-## If you want to deploy to Heroku
-golem::add_dockerfile_heroku()
+## In command line.
+rsconnect::deployApp(
+  appName = desc::desc_get_field("Package"),
+  appTitle = desc::desc_get_field("Package"),
+  appFiles = c(
+    # Add any additional files unique to your app here.
+    "R/",
+    "inst/",
+    "data/",
+    "NAMESPACE",
+    "DESCRIPTION",
+    "app.R"
+  ),
+  appId = rsconnect::deployments(".")$appID,
+  lint = FALSE,
+  forceUpdate = TRUE
+)
